@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# GS Nodegraph Copyright 2019-2021 by Noah Rahm and contributors
+# gsnodegraph Copyright 2019-2021 by Noah Rahm and contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License" ;
 # you may not use this file except in compliance with the License.
@@ -66,3 +66,7 @@ SELECTION_BOX_BORDER_COLOR = (194, 194, 194, 255)
 SELECTION_BOX_COLOR = (100, 100, 100, 56)
 
 GRAPH_BACKGROUND_COLOR = (36, 37, 40, 255)
+
+BTN_NORMAL_COLOR = (0, 0, 0, 0)
+BTN_CLICKED_COLOR = (90, 127, 200, 255)
+BTN_FOCUSED_COLOR = (54, 56, 60, 255)
